#
# spec file for package goffice
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           goffice
Version:        0.10.55
Release:        bp155.1.6
Summary:        GLib/GTK+ Set of Document-Centric Objects and Utilities
License:        GPL-2.0-only OR GPL-3.0-only
Group:          System/GUI/GNOME
URL:            http://www.gnumeric.org/
Source:         https://download.gnome.org/sources/goffice/0.10/%{name}-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  ghostscript-devel >= 9.06
BuildRequires:  intltool
BuildRequires:  libgsf-devel >= 1.14.24
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(cairo) >= 1.10.0
BuildRequires:  pkgconfig(cairo-pdf) >= 1.10.0
BuildRequires:  pkgconfig(cairo-ps) >= 1.10.0
BuildRequires:  pkgconfig(cairo-svg) >= 1.10.0
BuildRequires:  pkgconfig(gdk-pixbuf-2.0) >= 2.22.0
BuildRequires:  pkgconfig(gio-2.0) >= 2.38.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.38.0
BuildRequires:  pkgconfig(gmodule-2.0) >= 2.38.0
BuildRequires:  pkgconfig(gobject-2.0) >= 2.38.0
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 1.0.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.8.7
BuildRequires:  pkgconfig(lasem-0.4) >= 0.4.1
BuildRequires:  pkgconfig(librsvg-2.0) >= 2.22.0
BuildRequires:  pkgconfig(libspectre) >= 0.2.6
BuildRequires:  pkgconfig(libxml-2.0) >= 2.4.12
BuildRequires:  pkgconfig(libxslt)
BuildRequires:  pkgconfig(pango) >= 1.24.0
BuildRequires:  pkgconfig(pangocairo) >= 1.24.0

%description
GOffice is a GLib/GTK+ set of document-centric objects and utilities.

These are common operations for document-centric applications that are
conceptually simple, but complex to implement fully: plug-ins, load and
save documents, undo and redo.

%package -n libgoffice-0_10-10
Summary:        GLib/GTK+ Set of Document-Centric Objects and Utilities
# To make lang package installable
Group:          System/Libraries
Provides:       %{name} = %{version}

%description -n libgoffice-0_10-10
GOffice is a GLib/GTK+ set of document-centric objects and utilities.

These are common operations for document-centric applications that are
conceptually simple, but complex to implement fully: plug-ins, load and
save documents, undo and redo.

%if 0%{?suse_version} > 1210
%package -n typelib-1_0-GOffice-0_10
Summary:        Introspection bindings for GOffice
Group:          System/Libraries

%description -n typelib-1_0-GOffice-0_10
GOffice is a GLib/GTK+ set of document-centric objects and utilities.

This package provides the GObject Introspection bindings for GOffice.
%endif

%package devel
Summary:        Development files for GOffice
Group:          Development/Libraries/GNOME
Requires:       libgoffice-0_10-10 = %{version}
Obsoletes:      goffice-doc < %{version}
Provides:       goffice-doc = %{version}
%if 0%{?suse_version} > 1210
Requires:       typelib-1_0-GOffice-0_10 = %{version}
%endif

%description devel
GOffice is a GLib/GTK+ set of document-centric objects and utilities.

This package contains files needed to develop applications using
goffice.

%lang_package

%prep
%setup -q

%build
%configure \
    --disable-static\
    --enable-introspection
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
# Create directory for extern plugins
mkdir -p %{buildroot}%{_libdir}/goffice/0.10/plugins
%find_lang %{name}-%{version}
%fdupes %{buildroot}%{_datadir}

%post -n libgoffice-0_10-10 -p /sbin/ldconfig
%postun -n libgoffice-0_10-10 -p /sbin/ldconfig

%files -n libgoffice-0_10-10
%license COPYING COPYING-gpl2 COPYING-gpl3
%doc AUTHORS BUGS NEWS README
%{_libdir}/libgoffice-0.10.so.*
%dir %{_libdir}/goffice
%{_libdir}/goffice/%{version}/
%dir %{_datadir}/goffice
%{_datadir}/goffice/%{version}/
# Directory for external plugins
%dir %{_libdir}/goffice/0.10
%dir %{_libdir}/goffice/0.10/plugins

%files -n typelib-1_0-GOffice-0_10
%{_libdir}/girepository-1.0/GOffice-0.10.typelib

%files devel
%doc ChangeLog MAINTAINERS
%{_includedir}/libgoffice-0.10/
%{_libdir}/libgoffice-0.10.so
%{_libdir}/pkgconfig/libgoffice-0.10.pc
%{_datadir}/gir-1.0/GOffice-0.10.gir
# Own these repositories to not depend on gtk-doc while building:
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/gtk-doc/html
%doc %{_datadir}/gtk-doc/html/goffice-0.10/

%files lang -f %{name}-%{version}.lang

%changelog
* Sun Feb  5 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.10.55:
  + Configuration updates.
* Fri Jan 20 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.10.54:
  + Allow multiple data labels for series.
  + Fix accumulator problem with infinites.
  + Fix fraction-formatting overflow problem.
* Sun Sep 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.10.53:
  + Fix problem rendering "...E-xx" numbers.
  + Hack around introspection issue.
  + Fix crash in plot.
* Tue Apr 19 2022 Emily Gonyer <emilyyrose@gmail.com>
- Updated to version 0.10.52
  + Improve GOComboBox css styling.
  + Reimplement GOActionComboStack using GtkComboBox.
  + Introspection fixes.
  + Documentation fixes.
  + Fix go+{add,sub}_epsilon{,l} confusion in fallback code for win32.
  + Fix long double problem with go_dtoa.
* Fri Jan 21 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.10.51:
  + Do not clip markers in scatter plots.
  + Draw background and outline for data labels.
  + Fix go_fake_{ceil,floor} confusion.
  + Introspection updates.
  + Improve go_pow10 accuracy by avoiding pow as much as possible.
  + Take evasive action re g_memdup.
* Mon Sep 20 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Fri Jun 11 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.10.50:
  + Fix data update in matrix plots.
  + Fix rendering on high resolution monitors when scale is not 1.
  + Simplify regression equation code.
  + Use only 3 decimals for R^2 for regression lines.
  + Eliminate empty Special category from format selector.
  + Improve regression line equation for date axes.
* Thu Mar 18 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.10.49:
  + Fix ods format problem.
  + Fix axis line crash.
  + Add state and saved-state to GODoc.
* Thu Aug 20 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.10.48:
  + Avoid serializing empty graph data.
  + Clip data labels in XY plots.
  + Don't emit a critical for invalid series in Logarithmic fit.
  + Optimize GtkWidget embedding in the canvas.
  + Clip grid lines rendering to the plot area.
  + Speed up GocGroup for large number of children.
  + Make GocGroup usable as a widgetless canvas.
  + Avoid critical in document image handling.
  + Introspection fixes.
  + Speed up GocGroup for large number of children.
  + Stop checking for Xrender.
  + Plug leaks.
* Sat May  9 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.10.47:
  + Fix crash if a XY plot series has data labels but no valid
    data.
  + Fix criticals related to data labels.
  + Fix a drawing error in contour plots.
  + Ensure that all required dims have valid data in a valid
    series.
  + Fix legend order in bar plots.
  + Test plot series validity after a data change.
  + Fix crossing axis position.
  + Fix component duplication.
  + Fix library namespace issue.
  + Implement auto-by-extension for image files.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Fri Nov  8 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.10.46:
  + Fix equations edition inside charts.
  + Fix legend contents for contour plots.
  + Add more functions to inspect formats.
  + Fix UTF-8 problem with format "mmmmm".
* Fri Jun  7 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.10.45:
  + Fix crash in exponential smoothing with invalid y data.
  + Fix ring plot center size persistence.
  + Introspection fixes.
  + Work around gtk-doc bugs.
* Fri Nov 30 2018 bjorn.lie@gmail.com
- Update to version 0.10.44:
  + No changes, version bump only.
* Mon Aug 20 2018 bjorn.lie@gmail.com
- Update to version 0.10.43:
  + No changes, version bump only.
* Mon Aug 13 2018 bjorn.lie@gmail.com
- Update to version 0.10.42:
  + Fix box plots when only outliers lie outside of the box.
  + Introspection fixes.
  + Improve file saver api.
  + Avoid hash order dependency for plugins.
  + dtoa: ensure fpu rounding mode here.
  + Test fixes.
* Tue May  8 2018 bjorn.lie@gmail.com
- Update to version 0.10.41:
  + Avoid excess precision of graph ticks.
* Thu May  3 2018 bjorn.lie@gmail.com
- Update to version 0.10.40:
  + Introspection fixes (bgo#793684).
  + Fixes required for running with musl (bgo#794115).
  + Store last-known modtime for GODoc.
  + Option menus: handle markup for labels.
  + Improve font selector sizing a bit.
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Wed Mar 14 2018 luc14n0@linuxmail.org
- Update to version 0.10.39:
  + sinpi/cospi/tanpi/cotpi improvement.
- Drop pristine distro version > 12.x conditional for using GI
  bindings.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Sun Dec 31 2017 jengelh@inai.de
- --with-pic has no effect with --disable-static, so drop it.
* Fri Dec 29 2017 zaitor@opensuse.org
- Update to version 0.10.38:
  + Avoid a few dubious uses of deprecated gtk+ functions.
  + Reduce number of compiler warnings.
- Use plain make call again, fix build for old versions of
  openSUSE.
* Sat Dec  2 2017 luc14n0@linuxmail.org
- Update to version 0.10.37:
  + No visible changes for the users.
- Point fdupes to the data directory intead of build root, which is
  is a practice that must be avoided.
- Adopt the use of %%make_build macro instead of raw make command,
  following the best practices.
- Remove %%clean section once its use is redundant since RPM does
  this work now.
* Sun Nov 19 2017 luc14n0@linuxmail.org
- Update to version 0.10.36:
  + Bug Fixes:
  - Engineering format (bgo#785669).
  - Crash in 3D plots when X or Y values are missing
    (bgo#788437).
  - Documentation build with recent gtk-doc (bgo#788710).
  - Don't use invalid styles in legend from contour or surface
    plots imported from Excel (bgo#788861).
- Add gio-2.0, gmodule-2.0 and gobject-2.0 pkgconfig BuildRequires:
  they were being pulled by the already declared
  pkgconfig(glib-2.0) and used, since they all live in glib2-devel
  package.
- Add pkgconfig(libxml-2.0) BuildRequires: required dependency
  checked by configure. Note that it was already being used but
  not declared.
- Update typelib-1_0-GOffice-0_10 summary for something shorter and
  correct GOffice spelling in devel package summary.
* Tue Jul 11 2017 zaitor@opensuse.org
- Update to version 0.10.35:
  + Fix quad-precision overflow problem.
* Tue Mar 21 2017 dimstar@opensuse.org
- Update to version 0.10.34:
  + Fix rich-text format problem.
* Tue Jan 31 2017 firebird209@gmail.com
- Update to version 0.10.33:
  + Make box plots look like bar plots in legends (bgo#773825).
  + Fix conditional compilation for long double (bgo#774439).
  + Reimplement major grids for discrete axes (bgo#775624).
  + Fix add child menu in graph guru (bgo#777336).
  + Fix evaluation of regression curves for area plots
    (bgo#777334).
  + Introspection fixes.
* Sat Aug 20 2016 zaitor@opensuse.org
- Update to version 0.10.32:
  + Avoid gnome-common dpendency.
  + Plug leak.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
* Thu Jun 30 2016 zaitor@opensuse.org
- Update to version 0.10.31:
  + No changes, versionbump only.
* Sun Jun 19 2016 zaitor@opensuse.org
- Update to version 0.10.30:
  + Fix color scale reference to its axis (bgo#766829).
* Sat May  7 2016 zaitor@opensuse.org
- Update to version 0.10.29:
  + Do not load invalid data labels in XYcolor plots (bgo#765155).
  + Fix an infinite loop condition in 3D plots (bgo#765480).
  + Implement line width and fill pattern support in themes
    (bgo#765970).
  + Improve go_complex_sqrt.
  + Improve go_complex_div.
* Wed Mar 23 2016 dimstar@opensuse.org
- Update to version 0.10.28:
  + Fix histograms with missing values (bgo#763446).
  + Configuration fixes.
  + Introspection improvements.
* Sat Feb  6 2016 zaitor@opensuse.org
- Update to version 0.10.27:
  + Support new foreign element in ODF export of time styles.
  + Add title to axis lines (bgo#760675).
  + Fix go_complex_powl accuracy for real case.
  + Fix go_complex_div for very small divisor.
* Tue Dec 29 2015 dimstar@opensuse.org
- Update to version 0.10.26:
  + Version bump only to stay in sync for gnumeric.
* Sat Dec 26 2015 damjanovic.ivo@gmail.com
- Update to version 0.10.25:
  + Plug leaks.
  + Fix axis editing bug (bgo#684886).
  + Make builds more reproducible.
* Fri Nov 27 2015 zaitor@opensuse.org
- Update to version 0.10.24:
  + Fix bounds and distance for rectangle and paths in RTL mode
    (bgo#753963).
  + Don't access NULL X or Y values in YXZ matrix plots
    (bgo#754590).
* Mon Aug  3 2015 zaitor@opensuse.org
- Update to version 0.10.23:
  + Disable metafiles support when there is no screen (bgo#748493).
  + Fix ABR (bgo#749167).
  + Shield Cairo from image sizes it cannot handle (bgo#749274).
  + Plug leaks (bgo#749395).
  + Portability problem affecting macs (bgo#749463).
  + Fix log-fit problem (rh#1240470).
  + Fix general format for wide case (bgo#752839).
  + Fuzzed file fixes: bgo#750860, bgo#751059, bgo#751256,
    bgo#751257, bgo#751272, bgo#751925, bgo#752223, bgo#750047,
    bgo#751250.
* Sat Apr 18 2015 zaitor@opensuse.org
- Update to version 0.10.22:
  + Fix selection of axes using only part fo the plot area
    (bgo#746456).
  + Protect colored xy and bubble plots against NULL z values.
  + Update circular axis bounds after a unit change (bgo#746738).
  + Auto fill color made transparent for opened markers
    (bgo#691025).
  + Make manual scale really manual (bgo#700599).
  + Do not draw the line over the arrow head at start (bgo#745736).
  + Improve log axis bounds (bgo#745960).
  + Fix format used for stacked percentage graphs.
  + Don't force bar/col axis to include 0 for log axis.
  + Don't force radial plots to include 0 for log axis.
  + Rewrite pattern-fill rendering (bgo#747212).
  + Add go_cotpi and go_atan2pi.
  + Fix persistence of ring plot center size.
* Thu Mar  5 2015 dimstar@opensuse.org
- Update to version 0.10.21:
  + Ignore invalid values while checking data order (bgo#744200).
  + Ensure that GOPixbuf keeps the original data around
    (bgo#745297).
  + Fix sheet objects rendering, including widgets (bgo#744076).
  + Fix problem with linear solver.
  + Add arrow selector widget.
  + Fix rendering of dotted lines (bgo#744419).
  + Activate font part of graph theming.
  + Plug leaks.
  + Add tooltips to gradient selector.
  + Add tooltips to pattern selector.
  + GOImage fixes.
* Thu Feb  5 2015 dimstar@opensuse.org
- Update to version 0.10.20:
  + Ensure the validity of the dims property for linear regression
    curves.
  + Fix marker problem with line plots.
* Wed Jan 28 2015 zaitor@opensuse.org
- Update to version 0.10.19:
  + Allow rotation of axis line labels (bgo#740198).
  + Move the title with its axis parent (bgo#684777).
  + Implement canvas native scrolling. (bgo#741394).
  + Don't use a data vector with no valid value (bgo#741910).
  + Allow custom ticks and grid lines for axis lines (bgo#600482).
  + Don't loose any data in an histogram when using automatic bins
    (bgo#742996).
  + Fix canvas issues when removing items.
  + Switch from GtkColorSelDialog to GtkColorChooser (bgo##695634).
* Fri Sep 26 2014 zaitor@opensuse.org
- Update to version 0.10.18:
  + Fix saving of color map names (bgo#735298).
  + Fix grid line theme support (bgo#733403).
  + Fix default ticks position.
  + Fix font color theme support (deb#757611).
  + Fix saving color maps when directory does not exists
    (bgo#735008).
  + Fix color maps loading (bgo#735007).
  + Don't pass NULL to g_strtod() (bgo#735555).
  + Work around gtk+ ABI break for colour selector (bgo#733350).
* Wed Jul 16 2014 dimstar@opensuse.org
- Update to version 0.10.17:
  + Add control for 3D plots axes lengths (bgo#694746).
  + Fix test for buggy C library.
- Changes from version 0.10.16:
  + Don't use GDK_THREADS_* (bgo#728793]).
  + Fixed Gog3DBox properties editor.
  + Add a view class to Gog3DBox to support data that are view
    dependent.
  + Restore dashes with dots in charts lines.
  + Clean out old #ifdef mess.
  + Improve axis value computation.
  + Improve xml import/export of GOStyle.
- Changes from version 0.10.15:
  + Improve GOFormat export to ods.
  + Explicitly allow manual charts size (bgo#728134).
  + Fix automatic chart size for manual position (bgo#728391).
  + Fix text alignment (bgo#728752).
  + Portability improvements.
  + Fix UMR in graph view.
  + Improve GOFormat export to ods.
  + Improve testing.
  + Improve go_dtoa and use it for go_format_general.
* Sun Apr 13 2014 zaitor@opensuse.org
- Update to version 0.10.14:
  + Improve conditional format roundtrip through ODF (part of
    bgo#725852).
  + Fix canvas drawing problem.
  + Work on conditional formats for ODF.
  + Implement numbered colours in number formats.
  + Fix plugin deactivation.
  + Plug leaks.
  + Fix rounding problem.
  + Use musl code for dtoa. Adapt to round-ties-away-from-0.
* Wed Mar 19 2014 dimstar@opensuse.org
- Update to version 0.10.13:
  + Write invisible characters in ODF number style export
    (part of bgo#725852).
  + Fix writing of scientific number format to ODF (bgo#725852).
  + Fix strict number style export to ODF (bgo#726237).
  + Ensure that the lasem plugin builds with lasem-0.4.1
    (bgo#725693).
  + Support leave_notify events in the canvas (bgo#668103).
  + Remove extra DESTDIR in mathml to itex converter (bgo#725684).
  + Fix problem saving print settings (bgo#698630).
  + Plug leaks.
  + Fix FMW problem with GocPolyline/GocPolygon.
* Tue Mar  4 2014 dimstar@opensuse.org
- Update to version 0.10.12:
  + New math equations component plugin.
- Add pkgconfig(libxslt) BuildRequires: new dependency.
* Sun Feb 16 2014 dimstar@opensuse.org
- Update to version 0.10.11:
  + No actual changes. Only some NEWS file reformatting.
* Wed Feb 12 2014 dimstar@opensuse.org
- Update to version 0.10.10:
  + bgo#719681: Fix graph guru appearance when used with gtk+-3.10.
  + Fix crasher in box plots (bgo#720310).
  + Fix elements number in polar plot series (bgo#720355).
  + Always save an axis position (bgo#722402).
  + Improve complex math, notably complex power.
  + Add quad precision log and hypot functions.
  + Add quad precision atan2, sin, sinpi, asin, cos, cospi, acos
    functions.
  + Add go_sinpi, go_cospi, go_tanpi, go_atan2pi.
  + Improve "General" format.
  + Improve Undo/Redo toolbar items.
  + Improve Color selector toolbar items.
  + Improve Pixmap selector toolbar items.
* Mon Dec  2 2013 dimstar@opensuse.org
- Update to version 0.10.9:
  + Improvements to quad precision code.
  + Fuzzed file isuues (bgo#712663).
* Wed Oct 16 2013 firebird209@gmail.com
- Update to version 0.10.8:
  + Do not destroy axes after adding a plot using a restricted set
    (bgo#708292).
  + Don't crash when there are no x values for a moving average
    smoothing (bgo#708562).
  + Never redefine GtkJustfication, use GoJustification instead
    (bgo#709007).
  + Build fixes.
  + Win32 work
  + Fix font selector crash (bgo#709438).
* Sun Sep  1 2013 zaitor@opensuse.org
- Update to version 0.10.7:
  + Version bump only, no changes from previous version.
* Wed Aug 28 2013 dimstar@opensuse.org
- Update to version 0.10.6:
  + Fix gtk+ 3.9 redraw problems (bgo#703124).
  + Fix NULL pointer issue in line plots (bgo#706663).
* Fri Aug 23 2013 zaitor@opensuse.org
- Update to version 0.10.5:
  + Don't crash on inconsistent format (bgo#705099).
  + Don't crash when loading an EMF image without valid data
    (bgo#704311).
  + Fixed text and path items positions (bgo#704391).
  + Don't crash when a pixbuf has an invalid size (bgo#704560,
    bgo#705005).
  + Fix area vs diameter selection in bubble plots bgo#705312).
  + Implement get_data_at_point for area and line plots
    (bgo#627277, bgo#689661).
  + Fix rendring of stacked area plots (bgo#705034).
  + Fix crash when drawing a fallback image without gtk
    (bgo#705677).
  + Fix crash in countour plots when no color is used (bgo#705913).
  + Add prescaling to go_linear_regression_leverage (bgo#703381).
  + Improve C standard compliance a tiny bit.
* Sat Jul 20 2013 dimstar@opensuse.org
- Update to version 0.10.4:
  + Fix crash on corrupted GOImage (bgo#703670).
  + Fix loading of image with invalid size or data (bgo#703740).
  + Don't use invalid GOImage arguments (bgo#703949).
  + Fix linear regression failure.
  + Add prescaling to linear regression (bgo#703381).
* Sat Jun 29 2013 zaitor@opensuse.org
- Update to version 0.10.3:
  + Implement color scales (bgo#695829).
  + Allow color scales to have titles (bgo#688595).
  + Allow regression equation frame to rotate with text
    (bgo#701546).
  + New matrix plots (bgo#657918, bgo#680806).
  + Set a minimal size for the graph property box (bgo#699473).
  + Fix crash when loading an invalid graph with a custom theme
    (bgo#702887).
  + Fix issue with librsvg includes (bgo#695167).
  + Make linear regression handle the case where the input columns
    are not independent (bgo#551457).
  + Install the unknown_image icon from Gnumeric (bgo#700742).
* Fri May  3 2013 dimstar@opensuse.org
- Update to version 0.10.2:
  + Fix locale directory.
  + Plug leaks.
  + Enhance canvas with possibility of css.
  + Improve printing of grey patterns.
  + Make narrow versions of combos for vertical toolbars.
  + Bugs fixed: bgo#696569, bgo#696647, bgo#696533, bgo#696825,
    bgo#697243, bgo#698057, bgo#698101, bgo#698102, bgo#698150,
    bgo#698162, bgo#698534, bgo#698867, bgo#695550, bgo#695031,
    bgo#696022.
- Drop goffice-configure.patch: fixed upstream.
- Drop gnome-common BuildRequires and call to gnome-autogen.sh, as
  we no longer carry any patches.
* Tue Mar 19 2013 dimstar@opensuse.org
- Update to version 0.10.1:
  + Don't add an extra separator at start of data labels
    (bgo#691704).
  + Don't crash after deleting a named smoothed curve (bgo#691796).
  + Fix data label offset serialization (bgo#692305).
  + Add a user interface for radar and polar plots axis
    selection (bgo#692803).
  + Fix go_component_build_snapshot() returned value.
    (bgo#694231).
  + Do not use invalid values in line plots (bgo#694232).
  + Make data labels position independant on scale (bgo#694731).
  + Cleanup linear algebra (bgo#691630).
  + Work on new compiler warnings.
  + Add efficient code for computing leverages (bgo#691913).
  + Introspection fixes.
  + Fix missing tooltip in color palette (bgo#695032).
  + Fix missing tooltip in pixmap selector.
- Add pkgconfig(lasem-0.4) BuildRequires: enable MathML rendering.
- Add ghostscript-devel BuildRequires: we have the right version
  available now.
- Add goffice-configure.patch: Fix install location of locale
  files.
- Add gnome-common BuildRequires and call to gnome-autogen.sh, as
  above patch touches the build system.
* Sun Feb 17 2013 zaitor@opensuse.org
- Remove openSUSE version conditional on
  pkgconfig(gobject-introspection-1.0) BuildRequires, configure now
  checks for it.
* Wed Dec 19 2012 dimstar@opensuse.org
- Update to version 0.10.0:
  + No further changes. Code-identical to 0.9.91.
- Changes from version 0.9.91:
  + Fixed typos in locales list (bgo#688977).
- Rename libgoffice-0_10-9 to libgoffice-0_10-10, following
  upstreams soname change.
* Tue Dec 11 2012 vuntz@opensuse.org
- Update to version 0.9.90:
  + Handle some more unusual formats in ODF export (bgo#683801)
  + Fix some magic date handling (bgo#686575)
  + Fix placement of minus sign (bgo#686575)
  + Add 'force exponent sign' checkbox to format selector
    (bgo#686481)
  + Fix export of scientific number format to ODF.
  + Fix rendering of fraction formats in locales with ' ' as
    thousand separator (bgo#686471)
  + Updated locales (bgo#682749)
  + New scattered min-max plot type (bgo#683493)
  + Don't crash when no valid data is available for histograms
    (bgo#684047)
  + Clip histograms to the plot area (bgo#684195)
  + Fix backplane position when data are nearly all the same
    (bgo#684599)
  + Fixed crash when using data labels after gtk+ behavior change
    (bgo#684889)
  + Accept an offset up to 20 for graph data labels (bgo#684892)
  + Removed span tab 3D axes that don't support it (bgo#685405)
  + Don't draw a marker in the legend when not needed (bgo#685484)
  + Restore pixel aligned lines (bgo#686476)
  + Fixed position of rotated label frame (bgo#686478)
  + Fixed image clipping (bgo#686490)
  + Improve padding between axis ticks and labels (bgo#686473)
  + Enhance graph guru behavior when an object is deleted
    (bgo#687102)
  + Allow colors selection for contour and map plots (bgo#657908)
  + Don't crash when loading an xls file with an EMF picture
    (bgo#688047)
  + Namespace cleanup (bgo#686501)
  + Fix EE-format compilation (bgo#686480)
  + Plug leak.
* Sun Sep 16 2012 dimstar@opensuse.org
- Update to version 0.9.6:
  + Add comments for translators to SI units names (bgo#681813)
  + Use NAN instead of 0 for XYZ plots when data are missing
    (bgo#680486)
  + Add series name to legend for contour plots (bgo#680508)
  + Fix contour plot cardinality when axis bounds can't be
    retrieved (bgo#680512)
  + Allow axis choice for pseudo-3d plots (bgo#680636)
  + Allow filling to axis limits (bgo#680513)
  + Save axis Id for all axes, not only X and Y (bgo#680739)
  + Fix strings inconsistencies (3d vs. 3D) (bgo#681777)
  + Fix a crash for infinite values in XYZ contour plots
    (bgo#841840)
  + Fixed typos in translated string. (bgo#681779, bgo#681811,
    bgo#681812)
  + Minute accuracy improvement to matrix inversion.
  + Fix build with libspectre. (bgo#681846)
* Thu Aug 16 2012 dimstar@opensuse.org
- Update to version 0.9.5:
  + Fix spacing in chart properties dialog
  + Fix style inconsistency in regression trend line dialog
    (bgo#678810)
  + Fix rich text size evaluation (bgo#679459)
  + Moved prototypes from gog-axis-line-impl.h to gog-axis-line.h
  (bgo#679967)
- Changes from version 0.9.4:
  + Add go_pango_attrs_to_markup, partial inverse to
    pango_parse_markup
  + Handle underline tags as named tags in textbuffer
  + Add go_color_from_gdk_rgba
  + Fix item placement in linear & polynomial regression trend line
    dialog (bgo#678793)
  + Fix spacing in chart properties dialog (bgo#678812)
  + Fixed logfit equation typo (bgo#675560)
  + Fix text item position when clipped (bgo#676067)
  + Fix criticals when adding a trend line (bgo#676641)
  + Fix trend lines limits for impled X values.
* Sun Jun 17 2012 badshah400@gmail.com
- Install %%{_datadir}/gir-1.0/GOffice-0.10.gir only on openSUSE >
  12.1; this fixes build failures for openSUSE <= 12.1.
* Wed Apr 25 2012 vuntz@opensuse.org
- Update to version 0.9.3:
  + Add introspection support. [bgo#670161]
  + Fix output of scientific number formats to ODF. [bgo#672353]
  + Do not unneccessarily include numbers in number formats when
    exporting to ODF. [bgo#671860]
  + Fix GOImage fallback for non-GUI case.
  + Tweak bold attribute for rich text.
  + Fix minor multihead issue with help buttons in dialogs.
  + Eliminate GoComboText, use GtkComboBoxText instead.
  + Avoid critical in GOPixbuf code.
  + Work around intltool bug. [bgo#672771]
- Remove xz BuildRequires now that it comes for free in the build
  system.
- Add pkgconfig(gobject-introspection-1.0) BuildRequires to build
  introspection support.
- Change license from GPL-2.0 to "GPL-2.0 or GPL-3.0", following
  upstream change.
- Enable introspection support:
  + Create typelib-1_0-GOffice-0_10 subpackage.
  + Add typelib-1_0-GOffice-0_10 Requires to devel subpackage.
  + Only do this on openSUSE > 12.1, as we need libgsf with
    introspection support.
* Sat Mar  3 2012 dimstar@opensuse.org
- Update to version 0.9.2:
  + Improve sensitivity handling of SI related widgets in format
    selector.
  + Fix scientific format with SI prefix selection.
  + Fix recognition of formats with SI prefix by format selector.
  + Handle numeral shapes for number formats.
  + Fixed rounding errors in limits displayed in contour plot
    legend.
  + Support wrapped charts labels.
  + Fixed GdkPixbuf usage.
  + Don't truncate images when exporting a chart.
  + Add automatic Bezier spline interpolation.
  + Fixed graph type selector position.
  + Fix bounds for partial range logarithmic axes.
  + Fix Y-axis label position.
  + Add limits to the regression curve display range.
  + Don't move any other axis when changing an axis position.
  + Embed library ui files into library.
  + Embed svg-patterns.xml and error bar image files too.
  + Embed icons and ui files into plugins.
  + Bugs fixed: bgo#665301, bgo#665303, bgo#666292, bgo#643873,
    bgo#667005, bgo#645938, bgo#663356, bgo#667793, bgo#669257,
    bgo#669325, bgo#669252, bgo#669050.
* Mon Jan 23 2012 cfarrell@suse.com
- license update: GPL-2.0
  The canonical license of the spec file should be GPL-2.0
* Thu Jan 19 2012 vuntz@opensuse.org
- Add explicit pkgconfig() BuildRequires: cairo, cairo-pdf,
  cairo-ps, cairo-svg, gdk-pixbuf-2.0, glib-2.0, pango, pangocairo.
  Those were all implicitly brought in before.
- Add pkgconfig(libspectre) BuildRequires to enable EPS support.
- Remove pcre-devel BuildRequires: it's not needed anymore.
- Apply shared library packaging policy:
  + Create a libgoffice-0_10-9 subpackage.
  + Add a Provides for goffice to make lang subpackage
    installable.
  + Note that it's fine to ship the data files in this subpackage
    as they all live in a versioned directory.
  + Change goffice Requires in devel subpackage to
    libgoffice-0_10-9.
- Manually create %%{_libdir}/goffice/0.10/plugins directory in
  %%install, and own it: this is the directory for the external
  plugins.
* Mon Jan  9 2012 dimstar@opensuse.org
- Update to version 0.9.1:
  + High-precision accumulator improvements.
- Changes from version 0.9.0:
  + Port to gtk+-3.0
  + Make GSettings the default configuration backend
  + Remove GConf support
  + Add support for SVG images
  + Add some optional support for EPS images
  + Add resource manager for embedded files
  + Add a plugin directory for extern plugins, independent from
    micro version
  + Make sheet widgets scalable
  + Use pango attributes for formatting
  + Accept rich text in chart labels
  + Extend encoding specification from file-openers to plugin
    services
  + Support SI prefixes and units in scientific format selector
  + Recognize scientific formats with longer exponents
  + Fix output of scientific number formats with EE to ODF
  + Fix widgets position inside an RTL canvas
  + Fix problem with sticky format colouring
  + Bugs fixed: bgo#117215, bgo#417631, bgo#425685, bgo#513137,
    bgo#584380, bgo#588516, bgo#605434, bgo#623847, bgo#641901,
    bgo#647147, bgo#651561, bgo#654392, bgo#655573, bgo#656043,
    bgo#656056, bgo#656148, bgo#657187, bgo#657288, bgo#657379,
    bgo#657400, bgo#657670, bgo#657695, bgo#657696, bgo#658472,
    bgo#658527, bgo#660564, bgo#660917, bgo#661264, bgo#662393,
    bgo#662414, bgo#663078, bgo#663355, bgo#663717, bgo#664656.
- Clean spec-file using spec-cleaner.
- Replace gtk2-devel BuildRequires with pkgconfig(gtk+-3.0),
  following upstreams change to GTK 3.
- Drop gconf2-devel BuildRequires: with the move to GSettings this
  is no longer needed.
- Add pkgconfig(librsvg-2.0) BuildRequires: A newly introduced
  dependency to support SVG images.
- Remove explicit Requires from the -devel package: they are added
  automatically the pkgconfig()-way.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
* Mon Aug  1 2011 vuntz@opensuse.org
- Update to version 0.8.17:
  + Plug leaks.
  + Fix noisy leak. [bgo#652420]
* Fri Jun 17 2011 vuntz@opensuse.org
- Update to version 0.8.16:
  + Improve ODF 1.2 output of fraction format.
  + Fix long-double compilation issue.
  + Improve accuracy of complex power.
  + Fix GOFormat problem resulting in "-0". [bgo#650928]
- Stop using source service to download the tarball, as Factory
  will move away from this.
* Sun May 22 2011 dimstar@opensuse.org
- Update to version 0.8.15:
  + bgo#647324: Fix format string parsing with localized colour
    names.
  + bgo#646700: Fixed closed bezier spline evaluation.
  + bgo#646832: Implement dropbar plots with linear or logarithmic
    index axis.
  + bgo#647367: Fix legends for plots with marker only style.
  + bgo#649485: Don't use badly rounded values when clipping
    markers.
  + bgo#650515: Implement probability plots with data as y values.
  + Plug memory leaks.
  + Detect more cases of linear-regression gone bad.
* Mon Apr 18 2011 dimstar@opensuse.org
- Update to version 0.8.14:
  + bgo#643767: Implement a GSettings backend for GOConf.
  + bgo#644222: Fix gnumeric crash when monitoring settings changes
  + Fix memory leaks.
  + Allow GOConf to handle absolute keys.
- Convert to source service: download tar.bz2 file and update .spec
  file with correct version.
* Sun Mar 20 2011 dimstar@opensuse.org
- Update to version 0.8.13:
  + bgo#636158: Write text formats to ODF.
  + Fixed memory leaks found by cppcheck analysis.
  + bgo#638738: Fixed drop lines in line plots.
  + bgo#639840: Invalidate canvas items after reordering to force a
    redraw?
  + bgo#640438: Fix axis limits serialization.
  + bgo#640571: Fix problem with engineering formats.
* Sun Feb 27 2011 aj@suse.de
- Change lang package Requires to Recommends since it is not
  mandatory at runtime.
* Fri Nov 26 2010 dimstar@opensuse.org
- Update to version 0.8.12:
  + bgo#631242, bgo#630784: Fix US 30/360 date calculations.
  + bgo#631504: Fixed sorting with accentuated characters.
  + bgo#632310: Allow filled plots to be displayed behind the grids
  + Fixed patterns with cairo-1.10.
  + bgo#633735: Fixed flawed exponential fit in graphs for small
    values.
  + bgo#633965: Fixed an infinite loop condition in cubic spline
    evaluation.
  + Fix GOImage-vs-cairo lifecycle issue.
  + Fix loading of weird themes.
* Sat Oct  2 2010 vuntz@opensuse.org
- Update to version 0.8.11:
  + Implement custom grids in xyz plots. [bgo#624273]
  + Update API documentation.
  + Improve fractional days support for date axes.
  + Draw charset/locale selectors with "radio" buttons.
  + Fix charset problem for Japanese. [bgo#627829]
* Sun Sep  5 2010 vuntz@opensuse.org
- Update to version 0.8.10:
  + Make sure the first rather than the last error is shown.
  + Provide the opportunity of all errors to be shown.
  + Always use real line width when evaluating dashes. [bgo#442546]
  + Update x and y limits when data change for xyz plots.
    [bgo#627288]
  + Do not crash when displaying cubic spline with no abscissa.
    [bgo#627507]
  + Do not save image filling with no image. [bgo#627690]
  + Don't use g_free instead of xmlFree. [bgo#627700]
  + Optionaly delete trendlines from legend. [bgo#628031]
  + Fix critical in go_doc_finalize. [bgo#628467]
  + Fixed a potential crasher in
    gog_styled_object_document_changed. [bgo#628671]
  + Fixed GOImage references management. [bgo#628732]
  + Limit formats to sane number of decimals. [bgo#627066]
  + Fix minor go_string_replace issue.
  + Plug leaks.
  + Fix char-xmlChar confusion.
  + Fix graph crash. [bgo#628259]
  + Improve go_format_is_date.
  + Improve handling of date axes with time-of-day.
  + Fix FMR on image load. [Part of bgo#628467]
  + Updated translations.
* Tue Aug 17 2010 dimstar@opensuse.org
- Update to version 0.8.9:
  + bgo#626206, bgo#626263, bgo#626305: Don't crash when loading a
    corrupted chart.
  + Fix blur in zoomed charts.
  + bgo#626665: Fix memory leak and criticals in graph editor.
  + bgo#531070: Allow themes defined as xml files.
  + bgo#626461: Update currencies.
* Mon Aug  9 2010 vuntz@opensuse.org
- Update to version 0.8.8:
  + Make sure that go_format_sel_format_classification returns the
    value used by the format selector. [bgo#625454]
  + Do not take manually placed charts into account when evaluating
    rows and columns in GogGraph.
  + Fixed contour plots legend. [bgo#623887]
  + Add go_string_replace function.
  + Add functions to manage GOFormatDetails.
  + Fix go_conf notification problem. [bgo#625549]
  + Implement weekly ticks for date axes. [bgo#624340]
* Tue Jul 27 2010 andrea@opensuse.org
- Update to version 0.8.7:
  + Implement cumulative histograms.
  + Make histogram able to use raw data.
  + Implement equations rotation. [bgo#622782]
- Changes from version 0.8.6:
  + Clean-up some win32 code.
  + Fix point-on-graph crash. [bgo#620198]
  + Ensure format menu has yyyy-mm-dd.
  + Improve docs.
  + Fix currency ordering. [bgo#621336]
  + Fix rounding problems for very large numbers.
- Changes from version 0.8.5:
  + Fix the --without-gtk winbuild. [bgo#619312]
  + Fix trend-line problem with inverted x-axis. [bgo#619958]
- Changes from version 0.8.4:
  + Fix the --without-gtk build. [bgo#618592]
  + Regression fixes.
  + Improve linear regression accuracy.
  + Plug leaks.
- Changes from version 0.8.3:
  + Improve probability plots.
  + Implement the "combo-activate" signal in GOCombo. [bgo#583175]
  + Use markup for graph tips.
  + Fix week numbers issue.
  + Fix matrix inversion crash. [Part of bgo#617469]
  + Fix win32 configuration problem. [bgo#617672]
* Wed Apr 28 2010 dimstar@opensuse.org
- Update to version 0.8.2:
  + bgo#608422: Support fd:// URIs on win32
  + Add more GOPath API
  + bgo#613523: Implement conf notification in keyfile case
  + Fix distance calculation for arc, ellipse, polygon, polyline,
    and rectangle
  + Support rotation for text on canvas
  + Add PolyPolygon and Path
* Tue Mar  9 2010 dimstar@opensuse.org
- Update to version 0.8.1:
  + bgo#609833: Remove libglade dependency from pc file.
  + bgo#610434: Use gtk_buildable_get_name instead of
    gtk_widget_get_name where ppropriate.
  + bgo#610435: Fix crash in GogGuru.
  + bgo#611163: Fix cubic splines with invalid data.
  + bgo#611415: Fix locale selector issue.
  + Canvas improvements.
- Remove the libglade workaround.
* Sun Feb 14 2010 vuntz@opensuse.org
- Update to version 0.8.0:
  + Do not crash when a chart contains no plot. [bgo#607960]
  + Do not crash when deleting a grabbed item. [bgo#609747]
  + Add "autoload" flag for plugins.
  + Use locale independent markup. [bgo#608047]
* Sat Feb 13 2010 vuntz@opensuse.org
- Remove libglade-2.0 from libgoffice-0.8.pc with sed, until
  bgo#609833 gets fixed.
* Wed Jan 27 2010 vuntz@opensuse.org
- Update to version 0.7.18:
  + Fix description of ring plots. [bgo#606162]
  + Add a name to regression curves for display in legends.
    [bgo#605040]
  + Fixed GocPolygon bounds. [bgo#605496]
  + Moved plot area position page from plot to chart. [bgo#605771]
  + Add sample to the plot type selector. [bgo#495781]
  + Don't use multiline GtkLabel. [bgo#606162]
* Wed Dec 16 2009 vuntz@opensuse.org
- Update to version 0.7.17:
  + Fixed a canvas performance issue. [bgo#603813]
  + Update property page when style changes after reordering.
    [bgo#604229]
  + Fix context sensitive help support on win32.
  + Make GOCmdContext require less implementation.
* Fri Dec  4 2009 vuntz@opensuse.org
- Update to version 0.7.16:
  + Add parent name for new objects in the graph guru "Add" menu.
  + Fix configuration loading when using .gnumericrc. [bgo#600654]
  + Implement error bars in radar and polar plots. [bgo#572720]
  + Add an option for negative values display in pies and rings.
    [bgo#152614]
  + Add trend lines to legend. [bgo#383518]
  + Build color from color names usung gdk_parse_color.
    [bgo#601114]
  + Fix crashes in probablility and scatter plots. [bgo#603015,
    bgo#603016]
  + Support multiple series in probability plots. [bgo#603013]
  + Eliminate most uses of "float".
- Changes from version 0.7.15:
  + Fix bounds update of GocItem. [bgo#598091]
  + Prepare for GSEAL_ENABLE.
  + Display coordinates when moving the mouseover a graph.
    [bgo#382666]
  + Make titles the first logical child and ensure they are
    rendered last. Really fixes bgo#152675.
  + Fix graph scale after a size change. [bgo#599887]
  + Make chart position persistent in auto mode. [bgo#152674]
  + Canvas improvements for arrows.
- Changes from version 0.7.14:
  + Fix some translatable strings. [bgo#596003]
  + Fix unicolor gradient brightness.
  + Fix custom point marker in scatter plots. [bgo#596585]
  + Fixed various issues related to image filling.
  + Extensions for XLL support in Gnumeric. [bgo#597849]
* Tue Sep 29 2009 vuntz@opensuse.org
- Update to version 0.7.13:
  + Fix various problems with new canvas.
* Wed Sep  9 2009 dimstar@opensuse.org
- Update to version 0.7.12:
  + bgo#593608 - Deprecated GOStyle::outline.
  + bgo#593937, bgo#594070, bgo#594077 - Fixed import of surface
    plots from excel.
* Tue Sep  1 2009 vuntz@novell.com
- Update to version 0.7.11:
  + Fix canvas item realize/unrealize problems.  [bgo#593593]
* Mon Aug 31 2009 dimstar@opensuse.org
- Update to version 0.7.10:
  + Canvas improvements.
  + Removed FooCanvas.
  + Migrated from Glade to GtkBuilder.
  + bgo#592283 - Namespace issues.
- Drop libglade2-devel BuildRequires and Requires in devel package.
* Sun Aug 16 2009 dominique-obs@leuenberger.net
- Update to version 0.7.9:
  + bgo#586654 - Improve number style output to ODF.
  + Improve currency output to ODF.
  + bgo#587171 - Fix hang when writing date with invalid format.
  + bgo#585298 - Align surface ticks with grid.
  + bgo#589511, bgo#589512 - Fixed various contour plots related
    issues.
  + bgo#590416 - Comparison line for probability plots.
  + New cairo based canvas.
  + bgo#586567 - Fix format localization problem.
  + bgo#588138 - Fix crash with Win32 configuration.
  + bgo#590903 - Fix axis issues near zero.
  + bgo#590908 - Improve log-scale axes.
- No longer needed to rename sr@Latn to sr@latin.
* Mon Jun 22 2009 dominique-obs@leuenberger.net
- Update to version 0.7.8:
  + Add some odf GOFormat output utilities
  + Handle scale attributes in markup
  + Add functions to generate number formats
  + Make format classification function public
  + Fix inc/dec precision for accounting format
  + Introduce master include file
  + Activate formatting support for negative elapsed times.
* Sun May 24 2009 vuntz@novell.com
- Update to version 0.7.7:
  + Modified serialization of pango markup to support all weights
  + Add "pristine" as GODoc property.
  + Properly handle date conventions in graphs.
  + Support formatted editing of graph limits that are dates and
    times. [bgo#574681]
  + Implement new calendar button widget.
* Thu May  7 2009 vuntz@novell.com
- Update to version 0.7.6:
  + Fixed segfault during documentation generation. [bgo#580296]
  + Improve log axes' tick calculation. [bgo#375756]
* Mon Apr 27 2009 vuntz@novell.com
- Update to version 0.7.5:
  + Fixed gconf and gmathml propagation to pc file. [bgo#576497]
  + Added a new plot type: GogColorPolarPlot.
  + Use priority when looking up savers by extension or mime.
  + Add new go_format_is_time function.
  + Pick sane bounds for time-formatted axes.  [Part of bgo#574681]
  + Pick sane bounds for date-formatted axes.  [Part of bgo#574681]
  + Add magic date and time formats.
- Drop goffice-fix-gconf-dep.patch: fixed upstream.
* Mon Mar 23 2009 vuntz@novell.com
- Add goffice-fix-gconf-dep.patch to fix gconf detection in
  pkg-config.
* Mon Mar 23 2009 vuntz@novell.com
- Update to version 0.7.4:
  + Add go_gtk_show_url. [bgo#559021]
  + Don't display markers in histogram legend. [bgo#574340]
  + Skip points corresponding to invalid valies in pie charts.
    [bgo#574348]
  + Correctly use all points defined in bar/columns plot series.
    [bgo#574349]
  + Avoid unused direct shlib deps. [bgo#572910]
  + Set a default family when none is given. [bgo#575318]
  + Fix a pixbuf scaling problem in foocanvas.
  + Improve handling of localized formats.
* Mon Mar 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Thu Feb 26 2009 vuntz@novell.com
- Update to version 0.7.3:
  + Experimental support for equation using gmathml (disabled by
    default)
  + Add --without-long-double option. [bgo#557045]
  + Fixed various regressions in contour plots.
  + Add XYZ series based contour plots.
  + Drop the libgome dependency. [bgo#558709]
  + Made spline interpolation really use Bezier cubic splines.
  + Add closed Bezier and cubic spline interpolation.
  + Make drop lines go to the axis instead of chart bottom (or
    left).
  + Make possible to add an application specific custom widget to
    the graph editor.
  + Fixed critical in graph_typeselect_minor. [bgo#567931]
  + Fixed crash when adding series to bar chart. [bgo#572354]
  + Plug leaks.
  + Fix memory corruption issue. [bgo#561708]
  + Fix problem with formats like "0.0E-00". [bgo#563601]
  + Put the old 29-Feb-1900 problem to rest.
  + Fix fd://<n> uris after lobognomification.
  + Fix doc build with respect to the mathml stuff. [bgo#572483]
  + Clean up glib includes. [bgo#564021]
- Remove BuildRequires: gtk-doc, libgnomeui-devel
- Remove Requires of the devel package: libart_lgpl-devel,
  libbz2-devel, libgnome
- Merge the doc package in the devel package, and add the relevant
  Obsoletes/Provides.
- Remove unneeded autoreconf/intltoolize calls.
* Sat Jan 31 2009 vuntz@novell.com
- Use sr@latin instead of sr@Latn.
* Sun Jan 25 2009 vuntz@novell.com
- Remove BuildRequires and Requires on libgnomeprint-devel.
  Fix bnc#404826.
* Sat Jan 17 2009 crrodriguez@suse.de
- remove la files, baby step to kill references of libavahi-*.la
  distribution-wide
* Fri Oct 24 2008 maw@suse.de
- Update to version 0.7.2:
  + Bugs fixed: bgo#551128, bgo#500168, bgo#555161, bgo#555757,
    and bgo#550898.
* Thu Sep  4 2008 mboman@novell.com
- Updated to version 0.7.1:
  + Bugs fixed: bgo#348780, bgo#542506, bgo#543986, bgo#522458,
    bgo#545016, bgo#549249, bgo#534642, bgo#536276, bgo#442773,
    bgo#537541, bgo#482319, bgo#527249
  + Relaced remaining libart calls.
  + Reverse legend ordering for stacked 1.5d plots.
  + Added support for 3d plot axes and backplanes.
  + Implemented a user interface for 3d projection settings.
  + Work around valgrind bug.
  + Moved GOConf code from gnumeric to goffice.
  + Fixed plot types activation/deactivation issues.
  + Add singleton support to scatter and bars/columns plots.
  + Tune bubble size calc to be closer to other implementions.
  + Add EPS export for charts if cairo supports.
  + Enable the use of dolt.
  + Fix formats on win32.
  + Add go_format_is_invalid.
  + Improve date convention framework.
  + Fix problem with [Enter] causing infinite recursion.
* Tue Apr  1 2008 sbrabec@suse.cz
- Updated to version 0.6.2:
  * Set Length to 0 for invalid series in 1.5d plots. (bgo#514642)
  * Fix memory handling for 1.5d plots. (bgo#517995)
  * Automate library, headers, and .pc versioning.
  * Fix critical for bogus dates.  (bgo#511435)
  * Import Pango enhancements from Gnumeric.
  * Fix a crash when selecting a graph title. (bgo#501831)
  * Fix axis label position. (bgo#501000)
  * Handle inverted axis when clamping axis position.
  * Fix axis position warnings.
  * Fix increase of decimals for scientific notation. (bgo#500356)
  * Fix spurious cairo_show_page call when printing charts.
    (bgo#500017)
  * Fix another crash in gog_barcol_view_render. (bgo#498846)
  * Fix format problem with simplified exponential formats.
    (bgo#500393)
  * Fix crash in gog_barcol_view_render. (bgo#497777)
  * Improve classification of date formats.
  * Draw a frame around the graph area in graph editor.
  * Improve legend swatch appearance.
  * Populate the add button of the graph editor with more items.
  * Fix xy color scale when some data are missing. (bgo#475394)
  * Fix NULL pointer crash in gog_line_view_render(). (bgo#492485)
  * Add the ability to make a GogObject invisible.
  * Fix moving-average problem.  (bgo#491328)
  * Fix ABR in spline code.  (bgo#492158)
  * Fix crash in gog_renderer_update. (bgo#477052)
  * Copied FFT and complex numbers code from gnumeric.
  * Some extensions for OOX charts.
  * Fix format selector crash (bgo#475136).
  * Don't close image save as dialog after wrong extension.
    (bgo#420451)
  * Add function to test if a format has an hour field.
  * Re-enable GTK_DISABLE_DEPRECATED
  * Fix format dialog crash.  (bgo#480971)
  * Fill support for polar xy plots.
  * Interpolation support for polar plots.
  * Fix "fd://0" handling in go_shell_arg_to_uri.
  * Fix default date format.
  * Add function to tell month/day order in format.
* Wed Jan 30 2008 sbrabec@suse.cz
- Devhelp documentation moved to the separate package (bnc#248813).
- Removed unneeded .la files.
* Thu Aug  9 2007 jpr@suse.de
- Fix array overflow (#287073)
* Tue Aug  7 2007 maw@suse.de
- Use %%fdupes
- Split off a -lang subpackage
- s#%%run_ldconfig#/sbin/ldconfig/ in %%post and %%postun.
* Fri Aug  3 2007 jpr@suse.de
- Update to 0.4.2
- Foocanvas bug that scaled images by 1 extra pixel. (BGO #314864)
- Fix compilation for Gtk+ trunk.
- Fix chart guru help button. (BGO #394181)
- Minor memory leak.
- Make 64bit clean. (BGO #340552)
- Fault tolerance for unknown types on load. (BGO #419955)
- Fix icon paths on windows. (BGO #442707)
- Let file savers specify a mime type.
- Fix reversed-literal problem with formats.  (BGO #444247)
- Add support for cubic splines.
- Fix graph rendering on big endian machines. (BGO #432532)
* Tue Jul 10 2007 maw@suse.de
- Update to version 0.3.8, which:
- Adds preconditions to the text combo widget's API functions
- Fixes bugzilla.gnome.org #343507, #401588, and #431256.
- Add libbz2-devel and pcre-devel to the -devel subpackage
  Requires: section; while at it, resort it in alphabetical order.
* Tue Mar  6 2007 jhargadon@suse.de
- update to version 0.3.7
- Add more line styles
- Separate the format selector from format internals
- Total rewrite of number formatting
- Remove embedded PCRE
- Generalize number formatting
- Add a half pie plots
- Add initial support for moving objects by mouse
- Add a resolution setting in image export file chooser
- Add gtk-doc support
- Improve scientific format
- many bug fixes
* Tue Jan  9 2007 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Sat Sep 30 2006 aj@suse.de
- Cleanup BuildRequires.
* Wed Sep 27 2006 jhargadon@suse.de
- update to version 0.2.1
- Back port some fixes for free memory reads that were causing
  problems on freebsd
- Fixed a sign in equation [#328236]
* Wed Aug 30 2006 ro@suse.de
- make it build (undef GTK_DISABLE_DEPRECATED in go-combo-box.c)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Nov 16 2005 sbrabec@suse.cz
- Updated to version 0.1.2.
* Fri Nov  4 2005 sbrabec@suse.cz
- New SuSE package, version 0.1.0.
